RequestReferrerCallback class

Constructors

RequestReferrerCallback({required void startRequestReferrer(), required void requestSuccess(String referrer)})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
requestSuccess → void Function(String referrer)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startRequestReferrer → void Function()
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited